@@ -1,6 +1,8 @@
 #include "chm_common.h"
 #include "Mutils.h"
 
+cholmod_common c;
+
 static R_INLINE int
 check_class(char *class, char **valid)
 {
@@ -11,6 +13,16 @@ check_class(char *class, char **valid)
     }
 }
 
+/**
+ * Create a cholmod_sparse object with the contents of x.  Note that
+ * the result should *not* be freed with cholmod_sparse_free.  Use
+ * Free on the result.
+ *
+ * @param x pointer to an object that inherits from TsparseMatrix
+ *
+ * @return pointer to a cholmod_triplet object that contains pointers
+ * to the slots of x.
+ */
 cholmod_sparse *as_cholmod_sparse(SEXP x)
 {
     cholmod_sparse *ans = Calloc(1, cholmod_sparse);
@@ -66,7 +78,8 @@ cholmod_sparse *as_cholmod_sparse(SEXP x)
 	    (!strcmp(CHAR(asChar(getAttrib(x, Matrix_uploSym))), "U")) ?
 	    1 : -1;
 	break;
-    case 2: error("triangular matrices not yet mapped to CHOLMOD");
+    case 2: ans->stype = 0; break; /* Note that triangularity property is lost */
+/* 	error("triangular matrices not yet mapped to CHOLMOD"); */
     }
 
     return ans;
@@ -85,9 +98,10 @@ SEXP chm_sparse_to_SEXP(cholmod_sparse *a, int dofree)
 {
     SEXP ans;
     char *cl = "";		/* -Wall */
-    int *dims, nnz = cholmod_nnz(a, &c);
+    int *dims, nnz;
 				/* ensure a is sorted and packed */
     if (!a->sorted || !a->packed) cholmod_sort(a, &c);
+    nnz = cholmod_nnz(a, &c);
 				/* determine the class of the result */
     switch(a->xtype){
     case CHOLMOD_PATTERN:
@@ -130,7 +144,7 @@ SEXP chm_sparse_to_SEXP(cholmod_sparse *a, int dofree)
 /**
  * Create a cholmod_triplet object with the contents of x.  Note that
  * the result should *not* be freed with cholmod_triplet_free.  Use
- * free or Free on the result.
+ * Free on the result.
  *
  * @param x pointer to an object that inherits from TsparseMatrix
  *
@@ -190,7 +204,8 @@ cholmod_triplet *as_cholmod_triplet(SEXP x)
 	    (!strcmp(CHAR(asChar(getAttrib(x, Matrix_uploSym))), "U")) ?
 	    1 : -1;
 	break;
-    case 2: error("triangular matrices not yet mapped to CHOLMOD");
+    case 2: ans->stype = 0; break; /* Note that triangularity property is lost */
+/* 	error("triangular matrices not yet mapped to CHOLMOD"); */
     }
 
     return ans;
@@ -252,7 +267,7 @@ SEXP chm_triplet_to_SEXP(cholmod_triplet *a, int dofree)
 /**
  * Create a cholmod_dense object with the contents of x.  Note that
  * the result should *not* be freed with cholmod_dense_free.  Use
- * free or Free on the result.
+ * Free on the result.
  *
  * @param x pointer to an object that inherits from (denseMatrix ^ generalMatrix)
  *
